@@ -1,21 +1,21 @@
 /*
- *	cook - file construction tool
- *	Copyright (C) 1994, 1997, 1998, 1999 Peter Miller;
- *	All rights reserved.
+ *      cook - file construction tool
+ *      Copyright (C) 1994, 1997-1999, 2006, 2007 Peter Miller;
+ *      All rights reserved.
  *
- *	This program is free software; you can redistribute it and/or modify
- *	it under the terms of the GNU General Public License as published by
- *	the Free Software Foundation; either version 2 of the License, or
- *	(at your option) any later version.
+ *      This program is free software; you can redistribute it and/or modify
+ *      it under the terms of the GNU General Public License as published by
+ *      the Free Software Foundation; either version 2 of the License, or
+ *      (at your option) any later version.
  *
- *	This program is distributed in the hope that it will be useful,
- *	but WITHOUT ANY WARRANTY; without even the implied warranty of
- *	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *	GNU General Public License for more details.
+ *      This program is distributed in the hope that it will be useful,
+ *      but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *      MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *      GNU General Public License for more details.
  *
- *	You should have received a copy of the GNU General Public License
- *	along with this program; if not, write to the Free Software
- *	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
+ *      You should have received a copy of the GNU General Public License
+ *      along with this program; if not, write to the Free Software
+ *      Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
  *
  * MANIFEST: insulate against <stdlib.h> presence or absence
  */
@@ -23,7 +23,7 @@
 #ifndef COMMON_AC_STDLIB_H
 #define COMMON_AC_STDLIB_H
 
-#include <config.h>
+#include <common/config.h>
 
 #ifdef HAVE_STDLIB_H
 #include <stdlib.h>
@@ -74,7 +74,7 @@ typedef int wchar_t;
 
 /*
  * On Linux, the proptotype for exit isn't quite correct.
- *	(__NORETURN is the old gcc way, __NORETURN2 is the new gcc way.)
+ *      (__NORETURN is the old gcc way, __NORETURN2 is the new gcc way.)
  */
 #ifdef __linux__
 #ifdef __NORETURN
