@@ -1,22 +1,21 @@
 #!/bin/sh
 #
-#	cook - file construction tool
-#	Copyright (C) 1994, 1997, 1998 Peter Miller;
-#	All rights reserved.
+#       cook - file construction tool
+#       Copyright (C) 1994, 1997, 1998, 2007 Peter Miller
 #
-#	This program is free software; you can redistribute it and/or modify
-#	it under the terms of the GNU General Public License as published by
-#	the Free Software Foundation; either version 2 of the License, or
-#	(at your option) any later version.
+#       This program is free software; you can redistribute it and/or modify
+#       it under the terms of the GNU General Public License as published by
+#       the Free Software Foundation; either version 2 of the License, or
+#       (at your option) any later version.
 #
-#	This program is distributed in the hope that it will be useful,
-#	but WITHOUT ANY WARRANTY; without even the implied warranty of
-#	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-#	GNU General Public License for more details.
+#       This program is distributed in the hope that it will be useful,
+#       but WITHOUT ANY WARRANTY; without even the implied warranty of
+#       MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+#       GNU General Public License for more details.
 #
-#	You should have received a copy of the GNU General Public License
-#	along with this program; if not, write to the Free Software
-#	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
+#       You should have received a copy of the GNU General Public License
+#       along with this program; if not, write to the Free Software
+#       Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
 #
 # MANIFEST: Test the make2cook include functionality
 #
@@ -32,18 +31,18 @@ bin="$here/${1-.}/bin"
 
 fail()
 {
-	set +x
-	echo 'FAILED test of the make2cook include functionality' 1>&2
-	cd $here
-	rm -rf $work
-	exit 1
+        set +x
+        echo 'FAILED test of the make2cook include functionality' 1>&2
+        cd $here
+        rm -rf $work
+        exit 1
 }
 pass()
 {
-	set +x
-	cd $here
-	rm -rf $work
-	exit 0
+        set +x
+        cd $here
+        rm -rf $work
+        exit 0
 }
 trap \"fail\" 1 2 3 15
 
@@ -63,17 +62,20 @@ unset LANG
 MANPATH=${MANPATH-/usr/man}
 for path in ${AEGIS_SEARCH_PATH-$here}
 do
-	if test -d $path/lib/$LANG/.
-	then
-		MANPATH=${MANPATH}:$path/lib/$LANG
-	fi
+        if test -d $path/lib/$LANG/.
+        then
+                MANPATH=${MANPATH}:$path/lib/$LANG
+        fi
 done
 IFS="$ifs_old"
 
+TAB=`awk 'BEGIN{printf("\11")}' /dev/null`
+test $? -eq 0 || fail
+
 #
 # test make2cook include
 #
-cat > test.in << 'fubar'
+sed "s|<TAB>|$TAB|g" > test.in << 'fubar'
 override OBJ = snot
 .SUFFIXES:
 .include guano
@@ -83,7 +85,7 @@ test:;@echo OK
 fubar
 if test $? -ne 0 ; then fail; fi
 
-cat > test.ok << 'fubar'
+sed "s|<TAB>|$TAB|g" > test.ok << 'fubar'
 
 OBJ = snot;
 
@@ -92,8 +94,8 @@ OBJ = snot;
 #include-cooked-nowarn [wildcard [OBJ]]
 test:
 {
-	echo OK
-		set silent;
+<TAB>echo OK
+<TAB><TAB>set silent;
 }
 fubar
 if test $? -ne 0 ; then fail; fi
