@@ -1,22 +1,21 @@
 #!/bin/sh
 #
-#	cook - file construction tool
-#	Copyright (C) 1997, 1998, 2001, 2003 Peter Miller;
-#	All rights reserved.
+#       cook - file construction tool
+#       Copyright (C) 1997, 1998, 2001, 2003, 2007 Peter Miller
 #
-#	This program is free software; you can redistribute it and/or modify
-#	it under the terms of the GNU General Public License as published by
-#	the Free Software Foundation; either version 2 of the License, or
-#	(at your option) any later version.
+#       This program is free software; you can redistribute it and/or modify
+#       it under the terms of the GNU General Public License as published by
+#       the Free Software Foundation; either version 2 of the License, or
+#       (at your option) any later version.
 #
-#	This program is distributed in the hope that it will be useful,
-#	but WITHOUT ANY WARRANTY; without even the implied warranty of
-#	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-#	GNU General Public License for more details.
+#       This program is distributed in the hope that it will be useful,
+#       but WITHOUT ANY WARRANTY; without even the implied warranty of
+#       MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+#       GNU General Public License for more details.
 #
-#	You should have received a copy of the GNU General Public License
-#	along with this program; if not, write to the Free Software
-#	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
+#       You should have received a copy of the GNU General Public License
+#       along with this program; if not, write to the Free Software
+#       Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
 #
 # MANIFEST: Test the graph functionality
 #
@@ -34,26 +33,26 @@ bin="$here/${1-.}/bin"
 
 pass()
 {
-	set +x
-	cd $here
-	rm -rf $work
-	exit 0
+        set +x
+        cd $here
+        rm -rf $work
+        exit 0
 }
 fail()
 {
-	set +x
-	echo 'FAILED test of the graph functionality' 1>&2
-	cd $here
-	rm -rf $work
-	exit 1
+        set +x
+        echo 'FAILED test of the graph functionality' 1>&2
+        cd $here
+        rm -rf $work
+        exit 1
 }
 no_result()
 {
-	set +x
-	echo 'NO RESULT for test of the graph functionality' 1>&2
-	cd $here
-	rm -rf $work
-	exit 2
+        set +x
+        echo 'NO RESULT for test of the graph functionality' 1>&2
+        cd $here
+        rm -rf $work
+        exit 2
 }
 trap \"no_result\" 1 2 3 15
 
@@ -76,23 +75,23 @@ unset LANG
 cat > howto.cook << 'fubar'
 %.c %.h: %.y
 {
-	/*
-	 * Should not be run in this test, but it exersizes a variety of
-	 * backtracking in the build phase.
-	 */
-	yacc -d %.y;
-	mv y.tab.c %.c;
-	mv y.tab.h %.h;
+        /*
+         * Should not be run in this test, but it exersizes a variety of
+         * backtracking in the build phase.
+         */
+        yacc -d %.y;
+        mv y.tab.c %.c;
+        mv y.tab.h %.h;
 }
 
 %.o: %.c
 {
-	echo %.c + [need] > [target];
+        echo %.c + [need] > [target];
 }
 
 prog: a.o b.o c.o
 {
-	echo [need] > [target];
+        echo [need] > [target];
 }
 
 a.o: a.h b.h c.h(weak);
@@ -140,15 +139,18 @@ if test $? -ne 0 ; then fail; fi
 $bin/cook -nl -script > test.out
 if test $? -ne 0 ; then fail; fi
 
-cat > test.ok << 'fubar'
+TAB=`awk 'BEGIN{printf("\11")}' /dev/null`
+test $? -eq 0 || no_result
+
+sed "s|<TAB>|$TAB|g" > test.ok << 'fubar'
 #!/bin/sh
 
 #line 12 howto.cook
 if test ! -e a.o \
-	-o ! a.o -nt a.c \
-	-o ! a.o -nt a.h \
-	-o ! a.o -nt b.h \
-	-o c.h -nt a.o
+<TAB>-o ! a.o -nt a.c \
+<TAB>-o ! a.o -nt a.h \
+<TAB>-o ! a.o -nt b.h \
+<TAB>-o c.h -nt a.o
 then
 echo 'echo a.c + a.c a.h b.h c.h > a.o'
 ( echo a.c + a.c a.h b.h c.h > a.o )
@@ -157,9 +159,9 @@ fi
 
 #line 12 howto.cook
 if test ! -e b.o \
-	-o ! b.o -nt b.c \
-	-o ! b.o -nt b.h \
-	-o ! b.o -nt c.h
+<TAB>-o ! b.o -nt b.c \
+<TAB>-o ! b.o -nt b.h \
+<TAB>-o ! b.o -nt c.h
 then
 echo 'echo b.c + b.c b.h c.h > b.o'
 ( echo b.c + b.c b.h c.h > b.o )
@@ -168,8 +170,8 @@ fi
 
 #line 12 howto.cook
 if test ! -e c.o \
-	-o ! c.o -nt c.c \
-	-o ! c.o -nt c.h
+<TAB>-o ! c.o -nt c.c \
+<TAB>-o ! c.o -nt c.h
 then
 echo 'echo c.c + c.c c.h > c.o'
 ( echo c.c + c.c c.h > c.o )
@@ -178,9 +180,9 @@ fi
 
 #line 17 howto.cook
 if test ! -e prog \
-	-o ! prog -nt a.o \
-	-o ! prog -nt b.o \
-	-o ! prog -nt c.o
+<TAB>-o ! prog -nt a.o \
+<TAB>-o ! prog -nt b.o \
+<TAB>-o ! prog -nt c.o
 then
 echo 'echo a.o b.o c.o > prog'
 ( echo a.o b.o c.o > prog )
