@@ -1,22 +1,21 @@
 #!/bin/sh
 #
-#	cook - file construction tool
-#	Copyright (C) 1998, 2001, 2003 Peter Miller;
-#	All rights reserved.
+#       cook - file construction tool
+#       Copyright (C) 1998, 2001, 2003, 2007 Peter Miller
 #
-#	This program is free software; you can redistribute it and/or modify
-#	it under the terms of the GNU General Public License as published by
-#	the Free Software Foundation; either version 2 of the License, or
-#	(at your option) any later version.
+#       This program is free software; you can redistribute it and/or modify
+#       it under the terms of the GNU General Public License as published by
+#       the Free Software Foundation; either version 2 of the License, or
+#       (at your option) any later version.
 #
-#	This program is distributed in the hope that it will be useful,
-#	but WITHOUT ANY WARRANTY; without even the implied warranty of
-#	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-#	GNU General Public License for more details.
+#       This program is distributed in the hope that it will be useful,
+#       but WITHOUT ANY WARRANTY; without even the implied warranty of
+#       MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+#       GNU General Public License for more details.
 #
-#	You should have received a copy of the GNU General Public License
-#	along with this program; if not, write to the Free Software
-#	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
+#       You should have received a copy of the GNU General Public License
+#       along with this program; if not, write to the Free Software
+#       Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
 #
 # MANIFEST: Test the cascade-for functionality
 #
@@ -36,26 +35,26 @@ export PATH
 
 pass()
 {
-	set +x
-	cd $here
-	rm -rf $work
-	exit 0
+        set +x
+        cd $here
+        rm -rf $work
+        exit 0
 }
 fail()
 {
-	set +x
-	echo 'FAILED test of the cascade-for functionality' 1>&2
-	cd $here
-	rm -rf $work
-	exit 1
+        set +x
+        echo 'FAILED test of the cascade-for functionality' 1>&2
+        cd $here
+        rm -rf $work
+        exit 1
 }
 no_result()
 {
-	set +x
-	echo 'NO RESULT for test of the cascade-for functionality' 1>&2
-	cd $here
-	rm -rf $work
-	exit 2
+        set +x
+        echo 'NO RESULT for test of the cascade-for functionality' 1>&2
+        cd $here
+        rm -rf $work
+        exit 2
 }
 trap \"no_result\" 1 2 3 15
 
@@ -111,19 +110,22 @@ if test $? -ne 0 ; then no_result; fi
 cook -nl -script > test.out 2> LOG
 if test $? -ne 0 ; then cat LOG; fail; fi
 
-cat > test.ok << fubar
+TAB=`awk 'BEGIN{printf("\11")}' /dev/null`
+if test $? -ne 0 ; then no_result; fi
+
+sed "s|<TAB>|$TAB|g" > test.ok << fubar
 #!/bin/sh
 
 #line 6 howto.cook
 if test ! -e fred.o \\
-	-o ! fred.o -nt fred.c
+<TAB>-o ! fred.o -nt fred.c
 then
 echo '${CC} -c fred.c'
 ( ${CC} -c fred.c )
 test \$? -eq 0 || exit 1
 fi
 if test ! -e test \\
-	-o ! test -nt fred.o
+<TAB>-o ! test -nt fred.o
 then
 :
 fi
